==> nextcloud-32.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/ko.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "입력한 이름이 너무 김",
    "The given web address is too long" : "입력한 웹 주소가 너무 김",
    "The given legal notice address is too long" : "입력한 법적 고지가 너무 김",
    "The given privacy policy address is too long" : "입력한 개인 정보 취급 방침 주소가 너무 김",
    "The given slogan is too long" : "입력한 슬로건이 너무 김",
    "The given color is invalid" : "입력한 색상이 잘못됨",
    "Saved" : "저장됨",
    "The file was uploaded" : "파일을 업로드함",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "업로드한 파일의 크기가 php.ini의 upload_max_filesize를 초과함",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일의 크기가 HTML 폼에 지정한 MAX_FILE_SIZE를 초과함",
    "The file was only partially uploaded" : "파일이 일부분만 업로드됨",
    "No file was uploaded" : "업로드한 파일 없음",
    "Missing a temporary folder" : "임시 폴더 없음",
    "Could not write file to disk" : "디스크에 파일을 쓸 수 없음",
    "A PHP extension stopped the file upload" : "PHP 확장 기능에서 파일 업로드를 차단함",
    "No file uploaded" : "업로드한 파일 없음",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "사용자 정의 테마를 사용하고 있습니다. 테마 앱에서 해당 설정을 덮어쓸 수 있습니다.",
    "Theming" : "테마",
    "Appearance and accessibility" : "외형과 접근성",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "테마 앱이 활성화되었으나, PHP 모듈 “imagick”이 활성화되지 않았습니다. 파비콘 생성을 위해 해당 모듈을 설치하고 활성화하십시오.",
    "Dark theme with high contrast mode" : "고대비 모드의 어두운 테마",
    "Enable dark high contrast mode" : "고대비 모드의 어두운 테마 활성화",
    "Similar to the high contrast mode, but with dark colours." : "고대비 모드와 비슷하지만, 어두운 색을 사용합니다.",
    "Dark theme" : "어두운 테마",
    "Enable dark theme" : "어두운 테마 활성화",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "어두운 테마는 전체적인 광량을 줄여 사용자의 눈을 편안하게 합니다.",
    "System default theme" : "시스템 기본 테마",
    "Enable the system default" : "시스템 기본 테마 활성화",
    "Using the default system appearance." : "시스템 기본 테마 사용",
    "Dyslexia font" : "난독증용 글꼴",
    "Enable dyslexia font" : "난독증용 글꼴 활성화",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic은 난독증 때문에 읽기에 문제가 있는 사람들을 위해 디자인된 자유 글꼴입니다.",
    "High contrast mode" : "고대비 모드",
    "Enable high contrast mode" : "고대비 모드 활성화",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "쉬운 탐색을 위한 고대비 테마입니다. 색감이 나빠지지만 더 선명해집니다.",
    "Light theme" : "밝은 테마",
    "Enable the default light theme" : "기본 밝은 테마 활성화",
    "The default light appearance." : "기본 라이트 테마",
    "Legal notice" : "법적 고지",
    "Privacy policy" : "개인 정보 취급 방침",
    "Adjust the Nextcloud theme" : "Nextcloud 테마 사용자 정의",
    "Name" : "이름",
    "Web link" : "웹 링크",
    "a safe home for all your data" : "내 모든 데이터 안전 저장소",
    "Slogan" : "슬로건",
    "Legal notice link" : "법적 고지 링크",
    "Privacy policy link" : "개인 정보 취급 방침 링크",
    "Header logo" : "머리글 로고",
    "Upload new header logo" : "새 머리글 로고 업로드",
    "Favicon" : "파비콘",
    "Upload new favicon" : "새 파비콘 업로드",
    "User settings" : "사용자 설정",
    "Disable user theming" : "사용자 테마 설정 권한 비활성화",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "관리자의 테마 설정과 무관하게, 각 사용자는 해당 계정의 배경과 색상을 변경할 수 있습니다. 지정한 테마를 강제하고자 할 경우 이 토글을 켜십시오.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "테마를 사용하여 내 인스턴스와 지원하는 클라이언트의 모습을 변경할 수 있습니다. 테마는 모든 사용자에게 적용됩니다.",
    "Upload new logo" : "새 로고 업로드",
    "Logo" : "로고",
    "Advanced options" : "고급 설정",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "사용 중 문제가 발생했을 경우, {issuetracker}이슈 트래커{linkend}에 보고해주시기 바랍니다. 또한 디자인 부분에 참여하고 싶다면, {designteam}저희 디자인 팀{linkend}과 함께해주세요!",
    "Appearance and accessibility settings" : "외형과 접근성 설정",
    "Keyboard shortcuts" : "키보드 단축키",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "특정 상황에서, 키보드 단축키는 접근성 도구의 동작과 간섭을 일으킬 수 있습니다. 간섭 방지와 접근성 도구의 정확한 동작을 위해, 이곳에서 모든 키보드 단축키를 비활성화할 수 있습니다. 이는 앱에서 사용할 수 있는 모든 단축키 또한 비활성화합니다.",
    "Disable all keyboard shortcuts" : "모든 키보드 단축키 비활성화",
    "Move up" : "위로 이동",
    "Move down" : "아래로 이동",
    "No background has been selected" : "'배경화면 없음'이 선택됨",
    "Custom background" : "나만의 배경화면",
    "Plain background" : "일반 배경",
    "Default background" : "기본 배경",
    "Theme selection is enforced" : "테마가 강제로 선택됨",
    "Navigation bar settings" : "내비게이션 바 설정",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "내비게이션 바의 앱 순서를 설정할 수 있습니다. 첫번째로 배치된 앱이 로그인 후 또는 로고를 클릭할 경우 열릴 기본 앱으로 지정됩니다.",
    "The default app can not be changed because it was configured by the administrator." : "관리자 설정으로 인해 기본 앱을 변경할 수 없습니다.",
    "Reset default app order" : "기본 앱 순서 초기화",
    "Could not set global default apps" : "모든 계정에 적용될 기본 앱을 적용할 수 없음",
    "Default app" : "기본 앱",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "기본 앱은 로그인 직후 또는 상단 로고 클릭시 열리는 앱입니다. ",
    "Use custom default app" : "기본 앱 지정",
    "Global default app" : "모든 계정에 적용될 기본 앱 지정",
    "Global default apps" : "모든 계정에 적용될 기본 앱",
    "Default app priority" : "기본 앱 우선순위",
    "Reset to default" : "기본값으로 초기화",
    "Upload" : "업로드",
    "Remove background image" : "배경 그림 삭제",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "보편적 접근성은 매우 중요합니다. 저희는 웹 표준을 준수하며, 마우스 혹은 스크린리더와 같은 보조 소프트웨어 없이도 정상적인 사용이 가능한지에 대해 확인하고 있습니다. 또한, {guidelines}웹 콘텐츠 접근성 가이드라인{linkend} 2.1을 AA 수준 및 AAA 수준의 고대비 테마에서 준수하기 위해 노력하고 있습니다. "
},
"nplurals=1; plural=0;");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/ko.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "입력한 이름이 너무 김",
    "The given web address is too long" : "입력한 웹 주소가 너무 김",
    "The given legal notice address is too long" : "입력한 법적 고지가 너무 김",
    "The given privacy policy address is too long" : "입력한 개인 정보 취급 방침 주소가 너무 김",
    "The given slogan is too long" : "입력한 슬로건이 너무 김",
    "The given color is invalid" : "입력한 색상이 잘못됨",
    "Saved" : "저장됨",
    "The file was uploaded" : "파일을 업로드함",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "업로드한 파일의 크기가 php.ini의 upload_max_filesize를 초과함",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일의 크기가 HTML 폼에 지정한 MAX_FILE_SIZE를 초과함",
    "The file was only partially uploaded" : "파일이 일부분만 업로드됨",
    "No file was uploaded" : "업로드한 파일 없음",
    "Missing a temporary folder" : "임시 폴더 없음",
    "Could not write file to disk" : "디스크에 파일을 쓸 수 없음",
    "A PHP extension stopped the file upload" : "PHP 확장 기능에서 파일 업로드를 차단함",
    "No file uploaded" : "업로드한 파일 없음",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "사용자 정의 테마를 사용하고 있습니다. 테마 앱에서 해당 설정을 덮어쓸 수 있습니다.",
    "Theming" : "테마",
    "Appearance and accessibility" : "외형과 접근성",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "테마 앱이 활성화되었으나, PHP 모듈 “imagick”이 활성화되지 않았습니다. 파비콘 생성을 위해 해당 모듈을 설치하고 활성화하십시오.",
    "Dark theme with high contrast mode" : "고대비 모드의 어두운 테마",
    "Enable dark high contrast mode" : "고대비 모드의 어두운 테마 활성화",
    "Similar to the high contrast mode, but with dark colours." : "고대비 모드와 비슷하지만, 어두운 색을 사용합니다.",
    "Dark theme" : "어두운 테마",
    "Enable dark theme" : "어두운 테마 활성화",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "어두운 테마는 전체적인 광량을 줄여 사용자의 눈을 편안하게 합니다.",
    "System default theme" : "시스템 기본 테마",
    "Enable the system default" : "시스템 기본 테마 활성화",
    "Using the default system appearance." : "시스템 기본 테마 사용",
    "Dyslexia font" : "난독증용 글꼴",
    "Enable dyslexia font" : "난독증용 글꼴 활성화",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic은 난독증 때문에 읽기에 문제가 있는 사람들을 위해 디자인된 자유 글꼴입니다.",
    "High contrast mode" : "고대비 모드",
    "Enable high contrast mode" : "고대비 모드 활성화",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "쉬운 탐색을 위한 고대비 테마입니다. 색감이 나빠지지만 더 선명해집니다.",
    "Light theme" : "밝은 테마",
    "Enable the default light theme" : "기본 밝은 테마 활성화",
    "The default light appearance." : "기본 라이트 테마",
    "Legal notice" : "법적 고지",
    "Privacy policy" : "개인 정보 취급 방침",
    "Adjust the Nextcloud theme" : "Nextcloud 테마 사용자 정의",
    "Could not set global default apps" : "모든 계정에 적용될 기본 앱을 적용할 수 없음",
    "Navigation bar settings" : "내비게이션 바 설정",
    "Default app" : "기본 앱",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "기본 앱은 로그인 직후 또는 상단 로고 클릭시 열리는 앱입니다. ",
    "Use custom default app" : "기본 앱 지정",
    "Global default app" : "모든 계정에 적용될 기본 앱 지정",
    "Global default apps" : "모든 계정에 적용될 기본 앱",
    "Default app priority" : "기본 앱 우선순위",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "테마를 사용하여 내 인스턴스와 지원하는 클라이언트의 모습을 변경할 수 있습니다. 테마는 모든 사용자에게 적용됩니다.",
    "Name" : "이름",
    "Web link" : "웹 링크",
    "Slogan" : "슬로건",
    "a safe home for all your data" : "내 모든 데이터 안전 저장소",
    "Legal notice link" : "법적 고지 링크",
    "Privacy policy link" : "개인 정보 취급 방침 링크",
    "Remove background image" : "배경 그림 삭제",
    "Favicon" : "파비콘",
    "Logo" : "로고",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "관리자의 테마 설정과 무관하게, 각 사용자는 해당 계정의 배경과 색상을 변경할 수 있습니다. 지정한 테마를 강제하고자 할 경우 이 토글을 켜십시오.",
    "Disable user theming" : "사용자 테마 설정 권한 비활성화",
    "Move up" : "위로 이동",
    "Move down" : "아래로 이동",
    "Theme selection is enforced" : "테마가 강제로 선택됨",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "내비게이션 바의 앱 순서를 설정할 수 있습니다. 첫번째로 배치된 앱이 로그인 후 또는 로고를 클릭할 경우 열릴 기본 앱으로 지정됩니다.",
    "The default app can not be changed because it was configured by the administrator." : "관리자 설정으로 인해 기본 앱을 변경할 수 없습니다.",
    "Reset default app order" : "기본 앱 순서 초기화",
    "Custom background" : "나만의 배경화면",
    "Plain background" : "일반 배경",
    "Default background" : "기본 배경",
    "Keyboard shortcuts" : "키보드 단축키",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "특정 상황에서, 키보드 단축키는 접근성 도구의 동작과 간섭을 일으킬 수 있습니다. 간섭 방지와 접근성 도구의 정확한 동작을 위해, 이곳에서 모든 키보드 단축키를 비활성화할 수 있습니다. 이는 앱에서 사용할 수 있는 모든 단축키 또한 비활성화합니다.",
    "Disable all keyboard shortcuts" : "모든 키보드 단축키 비활성화",
    "Reset to default" : "기본값으로 초기화",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "사용 중 문제가 발생했을 경우, {issuetracker}이슈 트래커{linkend}에 보고해주시기 바랍니다. 또한 디자인 부분에 참여하고 싶다면, {designteam}저희 디자인 팀{linkend}과 함께해주세요!",
    "Appearance and accessibility settings" : "외형과 접근성 설정",
    "Header logo" : "머리글 로고",
    "Upload new header logo" : "새 머리글 로고 업로드",
    "Upload new favicon" : "새 파비콘 업로드",
    "User settings" : "사용자 설정",
    "Upload new logo" : "새 로고 업로드",
    "Advanced options" : "고급 설정",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "보편적 접근성은 매우 중요합니다. 저희는 웹 표준을 준수하며, 마우스 혹은 스크린리더와 같은 보조 소프트웨어 없이도 정상적인 사용이 가능한지에 대해 확인하고 있습니다. 또한, {guidelines}웹 콘텐츠 접근성 가이드라인{linkend} 2.1을 AA 수준 및 AAA 수준의 고대비 테마에서 준수하기 위해 노력하고 있습니다. ",
    "No background has been selected" : "'배경화면 없음'이 선택됨",
    "Upload" : "업로드"
},
"nplurals=1; plural=0;");
